pub struct MpsGraphDevice {
pub index: usize,
}Expand description
Device for the MPSGraph backend (Apple GPU).
Fields
index: usizeTrait Implementations
Sourceimpl Clone for MpsGraphDevice
impl Clone for MpsGraphDevice
Sourcefn clone(&self) -> MpsGraphDevice
fn clone(&self) -> MpsGraphDevice
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for MpsGraphDevice
impl Debug for MpsGraphDevice
Sourceimpl Default for MpsGraphDevice
impl Default for MpsGraphDevice
Sourcefn default() -> MpsGraphDevice
fn default() -> MpsGraphDevice
Returns the “default value” for a type. Read more
Sourceimpl Device for MpsGraphDevice
impl Device for MpsGraphDevice
Sourcefn device_count(_type_id: u16) -> usize
fn device_count(_type_id: u16) -> usize
Returns the number of devices available under the provided type id.
Sourcefn device_count_total() -> usize
fn device_count_total() -> usize
Returns the total number of devices that can be handled by the runtime.
Sourceimpl DeviceOps for MpsGraphDevice
impl DeviceOps for MpsGraphDevice
Sourceimpl PartialEq for MpsGraphDevice
impl PartialEq for MpsGraphDevice
impl Copy for MpsGraphDevice
impl Eq for MpsGraphDevice
impl StructuralPartialEq for MpsGraphDevice